Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Binding ¶
type Binding interface {
// OnChange registers a handler f that handles value changes.
// Note that f should not perform time-consuming operations.
OnChange(f func(interface{})) CancelFunc
}
Binding ...
func NewAsyncBinding ¶
NewAsyncBinding creates a binding that runs in a separate goroutine
type CancelFunc ¶
type CancelFunc func()
A CancelFunc tells an operation to abandon its work. A CancelFunc may be called by multiple goroutines simultaneously. After the first call, subsequent calls to a CancelFunc do nothing.
type Source ¶
type Source interface {
Binding
// Change updates the Source
Change(v interface{})
}
Source ...
func NewTickSource ¶
NewTickSource creates a Source that will send the current time after each tick
type Transform ¶
type Transform func(interface{}) interface{}
Transform converts interface{} to interface{}
type Value ¶
type Value interface {
Binding
// Load ...
Load() interface{}
// Store ...
Store(v interface{})
// Bind creates a binding to this value
Bind(b Binding) CancelFunc
}
Value ...
Click to show internal directories.
Click to hide internal directories.